"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getComponent = void 0;
var react_1 = __importDefault(require("react"));
var antd_1 = require("antd");
var moment_1 = __importDefault(require("moment"));
var Form_1 = require("../core/Form");
var Button_1 = require("./components/Button");
var Checkbox_1 = __importDefault(require("./components/Checkbox"));
var DatePicker_1 = __importDefault(require("./components/DatePicker"));
var FileUpload_1 = __importDefault(require("./components/FileUpload"));
var FormItem_1 = __importDefault(require("./components/FormItem"));
var ImageUpload_1 = __importDefault(require("./components/ImageUpload"));
var Input_1 = __importDefault(require("./components/Input"));
var Multiselect_1 = __importDefault(require("./components/Multiselect"));
var Select_1 = __importDefault(require("./components/Select"));
var metaforms_1 = require("metaforms");
var ArrayControl_1 = __importDefault(require("./components/ArrayControl"));
var ObjectControl_1 = __importDefault(require("./components/ObjectControl"));
var HorizontalLayout_1 = __importDefault(require("./layout/HorizontalLayout"));
var SegmentedSwitch_1 = require("./components/SegmentedSwitch");
var getComponent = function (props) {
    var _a, _b, _c;
    var _d, _e, _f, _g, _h, _j, _k;
    if ((0, Form_1.isControlArray)(props)) {
        return react_1.default.createElement(ArrayControl_1.default, __assign({}, props));
    }
    if ((0, Form_1.isControlObject)(props)) {
        return (react_1.default.createElement(ObjectControl_1.default, __assign({}, props)));
    }
    if ((0, Form_1.isControlAction)(props)) {
        if (props.field.control === 'button') {
            return (react_1.default.createElement(antd_1.Button, { onClick: props.onAction }, props.field.label));
        }
        return null;
    }
    if ((0, Form_1.isControlLayout)(props)) {
        if (props.field.render === 'horizontal') {
            return react_1.default.createElement(HorizontalLayout_1.default, null, props.children);
        }
        return react_1.default.createElement(react_1.default.Fragment, null, props.children);
    }
    var ref = props.ref, input = props.input, meta = props.meta, helpers = props.helpers, form = props.form;
    // todo better types
    var disabled = props.field.disabled || form.isSubmitting;
    if ((0, metaforms_1.isText)(props.field)) {
        return (react_1.default.createElement(FormItem_1.default, { label: props.field.label, errorMessage: meta.error, validation: props.field.validation },
            react_1.default.createElement(Input_1.default, { ref: ref, type: "text", name: props.field.name, value: input.value, disabled: disabled, placeholder: props.field.placeholder, onChange: input.onChange, onBlur: input.onBlur })));
    }
    if ((0, metaforms_1.isNumber)(props.field)) {
        return (react_1.default.createElement(FormItem_1.default, { label: props.field.label, errorMessage: meta.error, validation: props.field.validation },
            react_1.default.createElement(Input_1.default, { ref: ref, type: "number", name: props.field.name, value: input.value, disabled: disabled, placeholder: props.field.placeholder, onChange: input.onChange, onBlur: input.onBlur })));
    }
    if ((0, metaforms_1.isPassword)(props.field)) {
        return (react_1.default.createElement(FormItem_1.default, { label: props.field.label, errorMessage: meta.error, validation: props.field.validation },
            react_1.default.createElement(Input_1.default, { ref: ref, type: "password", name: props.field.name, value: input.value, disabled: disabled, placeholder: props.field.placeholder, onChange: input.onChange, onBlur: input.onBlur })));
    }
    if ((0, metaforms_1.isSelect)(props.field)) {
        return (react_1.default.createElement(Select_1.default, __assign({ ref: ref, label: props.field.label, error: meta.error, disabled: disabled, placeholder: props.field.placeholder, options: props.field.options }, input, { onChange: helpers.setValue })));
    }
    if ((0, metaforms_1.isTextarea)(props.field)) {
        return (react_1.default.createElement(FormItem_1.default, { label: props.field.label, errorMessage: meta.error, validation: props.field.validation },
            react_1.default.createElement(antd_1.Input.TextArea, { ref: ref, rows: props.field.rows, name: props.field.name, value: input.value, disabled: disabled, placeholder: props.field.placeholder, onChange: input.onChange, onBlur: input.onBlur })));
    }
    if ((0, metaforms_1.isCheckbox)(props.field)) {
        return (react_1.default.createElement(FormItem_1.default, { label: "", errorMessage: meta.error, validation: props.field.validation },
            react_1.default.createElement(Checkbox_1.default, __assign({ ref: ref, label: props.field.label, disabled: disabled }, input, { onChange: helpers.setValue }))));
    }
    if ((0, metaforms_1.isSubmit)(props.field)) {
        return react_1.default.createElement(Button_1.Submit, { label: props.field.label, isLoading: form.isSubmitting, fullWidth: props.field.fullWidth, name: props.field.name });
    }
    if ((0, metaforms_1.isDate)(props.field)) {
        return (react_1.default.createElement(FormItem_1.default, { label: props.field.label, errorMessage: meta.error, validation: props.field.validation },
            react_1.default.createElement(DatePicker_1.default, __assign({ ref: ref, disabled: disabled, placeholder: props.field.placeholder, withTimePicker: props.field.withTimePicker }, input, { onChange: helpers.setValue }))));
    }
    if ((0, metaforms_1.isImage)(props.field)) {
        return react_1.default.createElement(ImageUpload_1.default, __assign({ label: props.field.label, error: meta.error }, input, { onChange: helpers.setValue, multiple: props.field.multiple }));
    }
    if ((0, metaforms_1.isFile)(props.field)) {
        return react_1.default.createElement(FileUpload_1.default, __assign({ label: props.field.label, accept: props.field.accept, error: meta.error }, input, { onChange: helpers.setValue }));
    }
    if ((0, metaforms_1.isDateRange)(props.field)) {
        var value = ((_d = input.value) === null || _d === void 0 ? void 0 : _d.length) === 2 ? input.value : undefined;
        return (react_1.default.createElement(FormItem_1.default, { label: props.field.label, errorMessage: meta.error, validation: props.field.validation },
            react_1.default.createElement(antd_1.DatePicker.RangePicker, __assign({ ref: ref }, input, { format: props.field.withTimePicker ? 'DD.MM.YYYY HH:mm' : 'DD.MM.YYYY', showTime: props.field.withTimePicker, style: props.field.size === 'small' ? {} : { width: '100%' }, ranges: __assign(__assign(__assign({}, ((_e = props.field.presets) === null || _e === void 0 ? void 0 : _e.lastDay) && (_a = {}, _a[(_f = props.field.presets) === null || _f === void 0 ? void 0 : _f.lastDay] = [(0, moment_1.default)().subtract(1, 'day'), (0, moment_1.default)()], _a)), ((_g = props.field.presets) === null || _g === void 0 ? void 0 : _g.lastWeek) && (_b = {}, _b[(_h = props.field.presets) === null || _h === void 0 ? void 0 : _h.lastWeek] = [(0, moment_1.default)().subtract(1, 'week'), (0, moment_1.default)()], _b)), ((_j = props.field.presets) === null || _j === void 0 ? void 0 : _j.lastMonth) && (_c = {}, _c[(_k = props.field.presets) === null || _k === void 0 ? void 0 : _k.lastMonth] = [(0, moment_1.default)().subtract(1, 'month'), (0, moment_1.default)()], _c)), value: value ? [moment_1.default.unix(value[0]), moment_1.default.unix(value[1])] : undefined, onChange: function (v) { var _a, _b; return helpers.setValue([(_a = v === null || v === void 0 ? void 0 : v[0]) === null || _a === void 0 ? void 0 : _a.unix(), (_b = v === null || v === void 0 ? void 0 : v[1]) === null || _b === void 0 ? void 0 : _b.unix()]); } }))));
    }
    if ((0, metaforms_1.isMultiselect)(props.field)) {
        return (react_1.default.createElement(FormItem_1.default, { label: props.field.label, errorMessage: meta.error, validation: props.field.validation },
            react_1.default.createElement(Multiselect_1.default, { ref: ref, name: input.name, placeholder: props.field.placeholder, options: props.field.options, onChange: helpers.setValue, value: input.value, disabled: disabled, onBlur: input.onBlur, showFilterInput: props.field.showFilterInput, showSelectedCounter: props.field.showSelectedCounter })));
    }
    if ((0, metaforms_1.isAutocomplete)(props.field)) {
        return (react_1.default.createElement(FormItem_1.default, { label: props.field.label, errorMessage: meta.error, validation: props.field.validation },
            react_1.default.createElement(antd_1.AutoComplete, { ref: ref, value: input.value, disabled: disabled, options: props.field.options, onBlur: input.onBlur, placeholder: props.field.placeholder, onChange: function (v) { return helpers.setValue(v); } })));
    }
    if ((0, metaforms_1.isSegmentedSwitch)(props.field)) {
        return (react_1.default.createElement(FormItem_1.default, { label: props.field.label, errorMessage: meta.error, validation: props.field.validation, align: props.field.align },
            react_1.default.createElement(SegmentedSwitch_1.SegmentedSwitch, { value: input.value, name: input.name, onChange: helpers.setValue, options: props.field.options, disabled: props.field.disabled, size: props.field.size })));
    }
    return react_1.default.createElement(react_1.default.Fragment, null);
};
exports.getComponent = getComponent;
